.tree-view .MuiTreeItem-root{padding-left:.1rem;position:relative}.tree-view .MuiFormControlLabel-label,.tree-view .MuiTreeItem-label,.tree-view .MuiTypography-root{font-size:.8rem}.tree-view .MuiTreeItem-group{padding-left:1rem;position:relative}.MuiTreeItem-content,.MuiTypography-root.MuiTreeItem-label.MuiTypography-body1{height:2rem}.tree-view .MuiTreeItem-content:not(.no-before):before{content:"";height:.9rem;left:0;position:absolute;top:.85rem;transform:translateY(-50%);width:1.5rem}.tree-view .MuiFormControlLabel-root{align-items:center;display:flex;justify-content:flex-start;position:relative;text-align:left;top:-.1rem;white-space:nowrap;width:fit-content}@keyframes blink{0%{opacity:1}50%{opacity:.5}to{opacity:1}}.select_mode_enable{animation:blink 1s infinite;color:red!important;text-shadow:0 0 5px #ff0000b3,0 0 10px #fdc9c980}span.select_mode_disable{color:var(--text-color)!important}#disabled_div_enable{opacity:.3;pointer-events:none}.switch{background:#f8f9fb1a!important;scale:.75!important}.MuiFormControlLabel-label.Mui-disabled{color:var(--text-color)!important;font-style:italic}span>div>svg.MuiSvgIcon-root{scale:.8}.tree-view{background:#f8f9fb;overflow:auto;scroll-behavior:smooth}.y_scroll_enable{max-height:100%;overflow-y:scroll;scrollbar-width:auto}.x_scroll_enable{max-width:100%;overflow-x:scroll;scrollbar-width:auto}.y_scroll_disable{overflow-y:hidden}.x_scroll_disable{overflow-x:hidden}.MuiCheckbox-root{color:var(
    --checkbox-color
  )!important}.MuiCheckbox-colorSecondary.Mui-checked{color:var(
    --primary-color
  )!important}.border_true{border:1px solid #31333f33!important;border-radius:.5rem}.tree-view{background:#f8f9fb1a}li#\30{top:.6em}.tree-view::-webkit-scrollbar{background:#f8f9fb1a;height:12px;width:12px}.tree-view::-webkit-scrollbar-track{background:#f1f1f1;border-radius:10px}.tree-view::-webkit-scrollbar-thumb{background:#888;border-radius:10px}.tree-view::-webkit-scrollbar-thumb:hover{background:#555}.tree-view::-webkit-scrollbar-corner{background:#0000}
/*# sourceMappingURL=main.05f62868.css.map*/